function [t,x,binary_values] = masterscript_ode_param(volume,flowrate,reactiontime,Tg,Tr,ProI,Ap)

%% Function parameters
% volume: continuous stirred-tank reactor (CSTR) volume (microliters)
% flowrate: sum of the CSTR inflow volume of reactant's stock solutions (microliters/hour)
kflow = flowrate/volume;
% reactiontime: simulation endtime (hours)
timespan = 0:0.01:reactiontime;
% Tg: resulting concentration of Trypsinogen inflow inside the CSTR (millimols/liter)
% Tr: resulting concentration of Trypsin inflow inside the CSTR (millimols/liter)
% ProI: resulting concentration of Pro-Inhibitor inflow inside the CSTR (millimols/liter)
% Ap: resulting concentration of Aminopeptidase inflow inside the CSTR (millimols/liter)

%% Kinetic constants of the reactions in the network with AcAsp ProI

k.kflow = kflow;

% 'Auto-catalysis'   
k.kf_auto_tr = 82;
% Tr + Tg --> [Tr-Tg]
k.kr_auto_tr = 2.04;
% [Tr-Tg] --> Tr + Tg 
k.kc_auto_tr = 34.7987;
% [Tr-Tg] --> Tr + Tr

% 'Pro-inhibitor activation'	
k.kc_act = 71;
% [Tr-ProI] --> Tr + IntI
k.kf_act = 448;
% Tr + ProI --> [Tr-ProI]
k.Km_act = 3.5;
k.kr_act = k.Km_act*k.kf_act-k.kc_act;
% [Tr-ProI] --> Tr + ProI

% 'Delayed inhibitor activation'
k.kc_delay = 0.077;
k.Vmax_delay=k.kc_delay*Ap; 
% [Ap-IntI] --> Ap + I
k.Km_delay = 2.7;
% Ap + IntI --> [Ap-IntI]
% [Ap-IntI] --> Ap + IntI

% 'Trypsin inhibition by pro-inhibitor'	
k.kf_inh_aai = 1.49;
% Tr + ProI --> Tr-ProI

% 'Trypsin inhibition by intermediate inhibitor'
k.kf_inh_ai = 1.95;
% Tr + IntI --> Tr-IntI

% 'Trypsin inhibition by active inhibitor'
k.kf_inh_i = 43;
% Tr + I --> [Tr-I]

% 'Hydrolysis of active inhibitor'
k.kf_degr_i = 0.027;
% I --> I-OH

% 'Hydrolysis of intermediate inhibitor'
k.kf_degr_ai = 0.025;
% IntI --> IntI-OH

% 'Hydrolysis of pro-inhibitor'	
k.kf_degr_aai = 0.16;

% 'Non-catalyzed auto-activation'
k.kc_auto_tg = 0.0028;
% Tg + Tg --> Tr + Tg
    
%% Numerical integration

% Initial concentrations of the species
xo = zeros(1,13);
xo(1) = Tg;
xo(2) = Tr;
xo(3) = ProI;
            
% Integration
OPTIONS = odeset('MaxStep', 1/100, 'InitialStep', 1/100);
[t,x] = ode23t(@ode_trypsin_osc, timespan, xo, OPTIONS, k, kflow, xo);

% Ap and Ap-IntI
x(:,15)=(1+x(:,6)+2.7-((1+x(:,6)+2.7).^2-4.*x(:,6)).^(0.5))/2;
x(:,14)=1-x(:,15);

%% Second derivative sign change as a threshold for the binarization

dy_dx = diff(diff(x));
binary_values = zeros(size(dy_dx));
sign_changes = dy_dx<0;
binary_values(sign_changes) = 1;
            
end

